@@ -8,7 +8,7 @@ use warnings;
 use Moo;
 
 use HTTP::Tiny;
-use Types::Standard qw(Str InstanceOf);
+use Types::Standard qw(Str InstanceOf Bool);
 use URI::Escape qw(uri_escape_utf8);
 
 our $VERSION = 0.03;
@@ -30,6 +30,12 @@ has err => (
     isa => Str,
 );
 
+has redirect => (
+    is      => 'ro',
+    isa     => Bool,
+    default => sub { 0; },
+);
+
 sub get {
     my ($self, $url, $params) = @_;
     
@@ -82,7 +88,7 @@ Tropo::RestAPI::Base - Base class for REST-API part of Tropo
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
 =head1 AUTHOR
 
